[java-identity-provider COMMIT] in /trunk/idp-cas-api/src/main/java/net/shibboleth/idp/cas: proxy/ProxyIdentifiers.ja...

noreply at shibboleth.net noreply at shibboleth.net
Wed Sep 21 18:45:22 EDT 2016


Author: tzeller
Date: Wed Sep 21 18:45:22 2016
New Revision: 8417

URL: http://svn.shibboleth.net/view/java-identity-provider?rev=8417&view=rev
Log:
IDP-865 - Checkstyle

Modified:
    trunk/idp-cas-api/src/main/java/net/shibboleth/idp/cas/proxy/ProxyIdentifiers.java
    trunk/idp-cas-api/src/main/java/net/shibboleth/idp/cas/service/PatternServiceRegistry.java
    trunk/idp-cas-api/src/main/java/net/shibboleth/idp/cas/service/Service.java
    trunk/idp-cas-api/src/main/java/net/shibboleth/idp/cas/service/ServiceContext.java
    trunk/idp-cas-api/src/main/java/net/shibboleth/idp/cas/service/ServiceDefinition.java

Modified: trunk/idp-cas-api/src/main/java/net/shibboleth/idp/cas/proxy/ProxyIdentifiers.java
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-cas-api/src/main/java/net/shibboleth/idp/cas/proxy/ProxyIdentifiers.java?rev=8417&r1=8416&r2=8417&view=diff
==============================================================================
--- trunk/idp-cas-api/src/main/java/net/shibboleth/idp/cas/proxy/ProxyIdentifiers.java	(original)
+++ trunk/idp-cas-api/src/main/java/net/shibboleth/idp/cas/proxy/ProxyIdentifiers.java	Wed Sep 21 18:45:22 2016
@@ -29,25 +29,37 @@
 public class ProxyIdentifiers {
 
     /** Proxy-granting ticket ID. */
-    @Nonnull
-    private final String pgtId;
+    @Nonnull private final String pgTicketID;
 
     /** Proxy-granting ticket IOU. */
-    @Nonnull
-    private final String pgtIou;
+    @Nonnull private final String pgTicketIOU;
 
+    /**
+     * Constructor.
+     *
+     * @param pgtId proxy-granting ticket ID
+     * @param pgtIou proxy-granting ticket IOU
+     */
     public ProxyIdentifiers(@Nonnull final String pgtId, @Nonnull final String pgtIou) {
-        this.pgtId = Constraint.isNotNull(pgtId, "PGT cannot be null");
-        this.pgtIou = Constraint.isNotNull(pgtIou, "PGTIOU cannot be null");
+        pgTicketID = Constraint.isNotNull(pgtId, "PGT cannot be null");
+        pgTicketIOU = Constraint.isNotNull(pgtIou, "PGTIOU cannot be null");
     }
 
-    @Nonnull
-    public String getPgtId() {
-        return pgtId;
+    /**
+     * Get the proxy-granting ticket ID.
+     * 
+     * @return proxy-granting ticket ID
+     */
+    @Nonnull public String getPgtId() {
+        return pgTicketID;
     }
 
-    @Nonnull
-    public String getPgtIou() {
-        return pgtIou;
+    /**
+     * Get the proxy-granting ticket IOU.
+     * 
+     * @return proxy-granting ticket IOU
+     */
+    @Nonnull public String getPgtIou() {
+        return pgTicketIOU;
     }
 }

Modified: trunk/idp-cas-api/src/main/java/net/shibboleth/idp/cas/service/PatternServiceRegistry.java
URL: http://svn.shibboleth.net/view/java-identity-provider/trunk/idp-cas-api/src/main/java/net/shibboleth/idp/cas/service/PatternServiceRegistry.java?rev=8417&r1=8416&r2=8417&view=diff
==============================================================================
--- trunk/idp-cas-api/src/main/java/net/shibboleth/idp/cas/service/PatternServiceRegistry.java	(original)
+++ trunk/idp-cas-api/src/main/java/net/shibboleth/idp/cas/service/PatternServiceRegistry.java	Wed Sep 21 18:45:22 2016
@@ -59,15 +59,16 @@
 
     /**
      * Sets the list of service definitions that back the registry.
      * @param definitions List of service definitions, each of which defines a match pattern to evaluate a candidate
      *                    service URL.
      */
-    public void setDefinitions(@Nonnull @NonnullElements List<ServiceDefinition> definitions) {
-        Constraint.noNullItems(definitions, "Definitions cannot be null or contain null items");
+    public void setDefinitions(@Nonnull @NonnullElements final List<ServiceDefinition> serviceDefinitions) {
+        Constraint.noNullItems(serviceDefinitions, "Definitions cannot be null or contain null items");
         // Preserve order of services in map
-        this.definitions = new LinkedHashMap<>(definitions.size());
-        for (ServiceDefinition definition : definitions) {
-            this.definitions.put(definition, Pattern.compile(definition.getId()));
+        definitions = new LinkedHashMap<>(serviceDefinitions.size());
+        for (ServiceDefinition definition : serviceDefinitions) {
+            definitions.put(definition, Pattern.compile(definition.getId()));
         }
     }
 
@@ -79,7 +80,7 @@
 
     @Override
     @Nullable
-    public Service lookup(@Nonnull String serviceURL) {
+    public Service lookup(@Nonnull final String serviceURL) {
         Constraint.isNotNull(serviceURL, "Service URL cannot be null");
         for (ServiceDefinition def : definitions.keySet()) {
             log.debug("Evaluating whether {} matches {}", serviceURL, def);
@@ -59,15 +59,16 @@
     /**
      * Sets the list of service definitions that back the registry.
-     * @param definitions List of service definitions, each of which defines a match pattern to evaluate a candidate
-     *                    service URL.
+     * 
+     * @param serviceDefinitions List of service definitions, each of which defines a match pattern to evaluate a
+     *            candidate service URL.
      */

Modified: trunk/idp-cas-api/src/main/java/net/shibboleth/idp/cas/service/Service.java

[... 176 lines stripped ...]


More information about the commits mailing list